@@ -5,7 +5,7 @@ package Big5HKSCS;
 #
 # http://search.cpan.org/dist/Char-Big5HKSCS/
 #
-# Copyright (c) 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 INABA Hitoshi <ina@cpan.org>
 ######################################################################
 
 use 5.00503;    # Galapagos Consensus 1998 for primetools
@@ -24,7 +24,7 @@ use 5.00503;    # Galapagos Consensus 1998 for primetools
 # $VERSION = CORE::eval $VERSION;
 
 BEGIN { CORE::eval q{ use vars qw($VERSION) } }
-$VERSION = '1.05';
+$VERSION = '1.08';
 $VERSION = CORE::eval $VERSION;
 
 BEGIN {
@@ -146,7 +146,7 @@ END
 sub import {
 
     if (Ebig5hkscs::e("$filename.e")) {
-        if (exists $ENV{'SJIS_DEBUG'}) {
+        if (exists $ENV{'CHAR_DEBUG'}) {
             Ebig5hkscs::unlink "$filename.e";
         }
         elsif (Ebig5hkscs::z("$filename.e")) {
@@ -519,6 +519,7 @@ There are two steps there:
     Big5HKSCS::length(...);
     Big5HKSCS::substr(...);
     Big5HKSCS::index(...);
+    Big5HKSCS::rindex(...);
     Big5HKSCS::eval(...);
 
   functions:
@@ -2436,6 +2437,11 @@ programming environment like at that time.
  ISBN 10: 1-56592-370-7
  http://shop.oreilly.com/product/9781565923706.do
 
+ Perl Resource Kit -- Win32 Edition
+ Erik Olson, Brian Jepson, David Futato, Dick Hardt
+ ISBN 10:1-56592-409-6
+ http://shop.oreilly.com/product/9781565924093.do
+
  MODAN Perl NYUMON
  By Daisuke Maki
  2009/2/10
@@ -2635,6 +2641,9 @@ I am thankful to all persons.
  daily dayflower, 2008-06-25 perluniadvice
  http://d.hatena.ne.jp/dayflower/20080625/1214374293
 
+ Unicode issues in Perl
+ http://www.i-programmer.info/programming/other-languages/1973-unicode-issues-in-perl.html
+
  Jesse Vincent, Compatibility is a virtue
  http://www.nntp.perl.org/group/perl.perl5.porters/2010/05/msg159825.html
 
